@@ -3,7 +3,8 @@ package POE::Component::IRC::Plugin::BaseWrap;
 use warnings;
 use strict;
 
-our $VERSION = '0.010';
+our $VERSION = '1.001001'; # VERSION
+
 use Carp;
 use POE;
 use POE::Component::IRC::Plugin qw(:ALL);
@@ -54,17 +55,17 @@ sub new {
     if ( not exists $args{trigger} and ref $args{triggers} ne 'HASH' ) {
         croak "Neither 'trigger' nor 'triggers' arguments were specified";
     }
-    
+
     $self->{ $_ } = delete $args{ $_ } for keys %args;
-    
+
     return $self;
 }
 
 sub PCI_register {
     my ( $self, $irc ) = splice @_, 0, 2;
-    
+
     $self->{irc} = $irc;
-    
+
     $irc->plugin_register( $self, 'SERVER', qw(public notice msg) );
 
     return 1;
@@ -74,7 +75,7 @@ sub PCI_unregister {
     my $self = shift;
 
     delete $self->{irc};
-    
+
     return 1;
 }
 
@@ -132,9 +133,9 @@ sub _parse_input {
             or
             ( exists $self->{trigger} and $what =~ s/$self->{trigger}// )
     );
-    
+
     $what =~ s/^\s+|\s+$//g;
-    
+
     warn "Matched trigger: [ who => $who, channel => $channel, "
             . "what => $what ]"
         if $self->{debug};
@@ -190,7 +191,7 @@ sub _do_response {
 
     if ( $self->{auto} ) {
         $in_ref->{type} = $self->{response_types}{ $in_ref->{type} };
-    
+
         my $response_type = $in_ref->{type} eq 'public'
                         ? 'privmsg'
                         : $in_ref->{type};
@@ -222,6 +223,8 @@ __END__
 
 =encoding utf8
 
+=for stopwords PoCo bot usermask
+
 =head1 NAME
 
 POE::Component::IRC::Plugin::BaseWrap - base class for IRC plugins which need triggers/ban/root control
@@ -261,6 +264,11 @@ POE::Component::IRC::Plugin::BaseWrap - base class for IRC plugins which need tr
     <Zoffix> TimeBot, time
     <TimeBot> Zoffix, time over here is: Mon Mar 10 18:12:15 2008
 
+=head1 PoCo FLAVOR
+
+This distribution also contains L<POE::Component::IRC::Plugin::BasePoCoWrap>
+module, for wrapping L<POE::Component> stuff.
+
 =head1 DESCRIPTION
 
 The module is a base class which provides features such as limiting user
@@ -292,8 +300,8 @@ which is to be using this base class.
 
 The C<_make_default_args> sub must return a list of key/value pairs which
 represent the default arguments of the plugin's constructor (C<new()>
-method). Whatever you specify here may be overriden by giving
-plugin's constuctor same-named arguments. Whatever you specify here
+method). Whatever you specify here may be overridden by giving
+plugin's constructor same-named arguments. Whatever you specify here
 will be available in C<_make_response_message> and C<_make_response_event>
 as a key in plugin's object. In other words, the trigger is available
 as C<$self-E<gt>{trigger}> (C<$self> being passed in C<$_[0]>). Refer
@@ -370,10 +378,10 @@ The full message that the user has sent.
         return $in_ref;
     }
 
-The C<_make_response_event> sub is similiar to C<_make_response_message> sub
+The C<_make_response_event> sub is similar to C<_make_response_message> sub
 except this one defines what the event handler listening to
 C<response_event> (see constructor's documentation in PLUGIN DOCUMENTATION
-section) event will recieve, but see also C<_message_into_response_event()>
+section) event will receive, but see also C<_message_into_response_event()>
 below. The call to this sub looks like this basically:
 
     $self->{irc}->send_event(
@@ -381,7 +389,7 @@ below. The call to this sub looks like this basically:
     );
 
 The first element of C<@_> will be the plugin's object and the second
-element will be the same hashref as C<_make_response_message> sub recieves.
+element will be the same hashref as C<_make_response_message> sub receives.
 See C<_make_response_message> sub above for more information.
 
 =head2 C<_message_into_response_event>
@@ -463,7 +471,7 @@ nasty surprise for those who are just WAY TOO LAZY ;) )
 
         sub _start {
             $irc->yield( register => 'all' );
-            
+
             $irc->plugin_add(
                 'EXAMPLE' =>
                     POE::Component::IRC::Plugin::EXAMPLE->new
@@ -547,7 +555,7 @@ nasty surprise for those who are just WAY TOO LAZY ;) )
 
     =head3 C<response_event>
 
-        ->new( response_event => 'event_name_to_recieve_results' );
+        ->new( response_event => 'event_name_to_receive_results' );
 
     B<Optional>. Takes a scalar string specifying the name of the event
     to emit when the results of the request are ready. See EMITED EVENTS
@@ -598,7 +606,7 @@ nasty surprise for those who are just WAY TOO LAZY ;) )
     one or all of keys B<public>, B<notice> and B<privmsg> which indicates
     the type of messages: channel messages, notices and private messages
     respectively. The values of those keys are regexes of the same format and
-    meaning as for the C<trigger> argument (see above). 
+    meaning as for the C<trigger> argument (see above).
     Messages matching this
     regex will be considered as requests. The difference is that only messages of type corresponding to the key of C<triggers> hashref
     are checked for the trigger. B<Note:> the C<trigger> will be matched
@@ -693,7 +701,7 @@ nasty surprise for those who are just WAY TOO LAZY ;) )
 
     The event handler set up to handle the event, name of which you've
     specified in the C<response_event> argument to the constructor
-    (it defaults to C<irc_EXAMPLE>) will recieve input
+    (it defaults to C<irc_EXAMPLE>) will receive input
     every time request is completed. The input will come in C<$_[ARG0]>
     on a form of a hashref.
     The possible keys/values of that hashrefs are as follows:
@@ -743,51 +751,28 @@ which uses this base class as well as the bot that uses the plugin.
 
 L<POE::Component::IRC::Plugin::BasePoCoWrap>, L<POE::Component::IRC::Plugin>,
 
-=head1 AUTHOR
+=head1 REPOSITORY
 
-Zoffix Znet, C<< <zoffix at cpan.org> >>
-(L<http://zoffix.com>, L<http://haslayout.net>)
+Fork this module on GitHub:
+L<https://github.com/zoffixznet/POE-Component-IRC-Plugin-BaseWrap>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-poe-component-irc-plugin-basewrap at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=POE-Component-IRC-Plugin-BaseWrap>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+To report bugs or request features, please use
+L<https://github.com/zoffixznet/POE-Component-IRC-Plugin-BaseWrap/issues>
 
-=head1 SUPPORT
+If you can't access GitHub, you can email your request
+to C<bug-POE-Component-IRC-Plugin-BaseWrap at rt.cpan.org>
 
-You can find documentation for this module with the perldoc command.
+=head1 AUTHOR
 
-    perldoc POE::Component::IRC::Plugin::BaseWrap
+Zoffix Znet <zoffix at cpan.org>
+(L<http://zoffix.com/>, L<http://haslayout.net/>)
 
-You can also look for information at:
+=head1 LICENSE
 
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=POE-Component-IRC-Plugin-BaseWrap>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/POE-Component-IRC-Plugin-BaseWrap>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/POE-Component-IRC-Plugin-BaseWrap>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/POE-Component-IRC-Plugin-BaseWrap>
-
-=back
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008 Zoffix Znet, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-=cut
+You can use and distribute this module under the same terms as Perl itself.
+See the C<LICENSE> file included in this distribution for complete
+details.
 
+=cut
\ No newline at end of file
